--[[ EXAMPLE USAGE ]]
dofile(ModPath .. "automenubuilder.lua") -- run the auto menu builder file to have access to its functions

-- set up a demo mod table
TestMod = TestMod or {
  settings = {
    toggle = false, -- booleans turn into checkboxes
    slider = 0, -- number values turn into sliders by default
    slider_custom_range = 5, -- custom range is defined in the values table below
    multi = 1, -- by default this would turn into a slider, specifying the possible values in the values table below makes it a multi choice element
    input = "", -- string values turn into input fields
    submenu = { -- table values turn into sub menus, specifying values for a table type in the values table will pass down the values to children
      inherited_1 = 0,
      inherited_2 = 0
    }
  },
  values = {
    slider_custom_range = { 1, 10, 0.25 }, -- number values make a slider with min, max and step value
    multi = { "dialog_yes", "dialog_no" }, -- string values make a multi choice selector
    submenu = { -2, 2, 0.1 } -- setting the values for a table type will make all sub entries inherit those values
  },
  order = {
    submenu = -100 -- make sure submenu comes last
  }
}

Hooks:Add("MenuManagerBuildCustomMenus", "MenuManagerBuildCustomMenusTestMod", function(menu_manager, nodes)

  -- loads previously saved settings for that mod into the given table
  AutoMenuBuilder:load_settings(TestMod.settings, "testmod")

  -- automatically creates a mod options menu from a table containing key/value pairs
  -- the type of menu element created from a value in the table is determined by the value type
  -- localization ids are generated in the style: menu_IDENTIFIER_OPTION and menu_IDENTIFIER_OPTION_desc
  -- example for this mod: menu_testmod_slider, menu_testmod_slider_desc, menu_testmod_inherited_1, ...
  -- if no localization is available for an option name it is auto generated from the option name
  AutoMenuBuilder:create_menu_from_table(nodes, TestMod.settings, "testmod", "blt_options", TestMod.values --[[ optional ]], TestMod.order --[[ optional ]])

end)